// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#ifndef DTK_SCREEN_ACE_H
#define DTK_SCREEN_ACE_H

#include <stdio.h>
#include <stdlib.h>
#include <stdbool.h>
#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef int (*InitBackendPtr)();
typedef void (*DestroyBackendPtr)();
typedef bool (*SetProtectedWindowPtr)(int32_t /*window*/);
typedef bool (*RemoveProtectedWindowPtr)(int32_t /*window*/);
typedef bool (*SetScreenShotToolsPtr)(const char* /*name*/);
typedef bool (*RemoveScreenShotToolsPtr)(char* /*name*/);
typedef void (*FreeScreenShotToolsPtr)();

typedef struct _Screen_Ace {
    void *backend;
    bool isWayland;
    char *xdgSessionType;

    // init and destory
    InitBackendPtr InitBackend;
    DestroyBackendPtr DestroyBackend;

    SetProtectedWindowPtr SetProtectedWindow;
    RemoveProtectedWindowPtr RemoveProtectedWindow;
    SetScreenShotToolsPtr SetScreenShotTools;
    RemoveScreenShotToolsPtr RemoveScreenShotTools;
    FreeScreenShotToolsPtr FreeScreenShotTools;
} ScreenAce;

typedef struct _Screen_Ace *ScreenAcePtr;
extern ScreenAcePtr pScreenAce;

/**
 * @brief init dtkdisplay content
 */
int InitDtkDisplay();

/**
 * @brief destory dtkdisplay content
 */
void DestoryDtkDisplay();

/**
 * @brief set protected windowid to prohibit screenshot
 * @param window: window id
 * @return true: success
 */
bool SetProtectedWindow(int32_t window);

/**
 * @brief remove protected windowid to enable screenshot
 * @param window: window id
 * @return true: success
 */
bool RemoveProtectedWindow(int32_t window);

/**
 * @brief set screenshot tools blacklist
 * @param name: blacklist
 * @return true: success
 */
bool SetScreenShotTools(const char *name);

/**
 * @brief remove screenshot tools blacklist
 * @param name: blacklist
 * @return true: success
 */
bool RemoveScreenShotTools(char *name);

/**
 * @brief free screenshot tools pointer
 */
void FreeScreenShotTools();

#ifdef __cplusplus
}
#endif

#endif
